%  BLADE DESIGN

GeneralProperties;

% Blade Parameters

syms b positive; %Base in m 
syms h positive; %Thickness in m
syms l positive; % Length in m
syms kz positive; % Constant of the blade in N/m


% Blade Shape
alpha = 1.5; % Shape Factor between 1 (rectangle) and 1.5 (triangle)
% Equations
constant = kz == E*b*h^3/(4*l^3*alpha);
stress = SY/FoS == 6*P*l/(b*h^2);
frequency = (2*pi*f)^2 == nblades*kz/m;





%% Plot Fixed B

minb = 0.04; % Min value of b
maxb = 0.1; % Max value of b
bwidth = 0.005; %Stepwidth for b


figure(1);
hold on;
for i=minb:bwidth:maxb  

ratio = b == i;


S = solve([constant, stress, frequency, ratio], [b,h,l,kz]);

B = double(S.b)*1000;
H = double(S.h);
L = double(S.l);
Kz = double(S.kz);

p = plot(B, H*100000, 'b.', B, L*1000, 'g.');

title(strcat('Length and Height as fonction of Width for', ' FoS = ', num2str(FoS), ' and m = ', num2str(m),' kg'));
xlabel('Width in mm');
legend('Height in 100um', 'Length in mm')
% set(0,'defaultaxescolororder',[b; g]) %black and gray
% set(0,'defaultaxeslinestyleorder',{'-*',':'}) %or whatever you want
% p(1).Marker = '*';
% p(2).Marker = '+';
% ylabel(p(1), 'Height in mm');
% ylabel(p(2), 'Length in mm');

% [ax,p1,p2] = plotyy(B, H*1000, B, L);
% ylabel(ax(1), 'Height in mm');
% ylabel(ax(2), 'Length in mm');
% xlim([minb maxb]);
% p1.Marker = '*';
% p1.LineWidth = 2;
% p2.Marker = '+';
% p2.LineWidth = 2;

end
% vline = line([72,72],[250,500]);
% vline.Color = 'r';
% hline = refline([0,280]);
% hline.Color = 'r';
% hold off;


%% Plot Fixed L

minl = 0.25; % Min value of b
maxl = 0.5; % Max value of b
lwidth = 0.005; %Stepwidth for b

figure(2);

hold on;
for i=minl:lwidth:maxl  

ratio = l == i;


S = solve([constant, stress, frequency, ratio], [b,h,l,kz]);

B = double(S.b);
H = double(S.h);
L = double(S.l);
Kz = double(S.kz);

p = plot(L*1000, H*100000, 'b.', L*1000, B*1000, 'g.');
title(strcat('Width and Height as fonction of Length for', ' FoS = ', num2str(FoS), ' and m = ', num2str(m),' kg'));
xlabel('Length in mm');
legend('Height in 100 um', 'Width in mm')
% set(0,'defaultaxescolororder',[b; g]) %black and gray
% set(0,'defaultaxeslinestyleorder',{'-*',':'}) %or whatever you want
% p(1).Marker = '*';
% p(2).Marker = '+';
% ylabel(p(1), 'Height in mm');
% ylabel(p(2), 'Length in mm');

% [ax,p1,p2] = plotyy(B, H*1000, B, L);
% ylabel(ax(1), 'Height in mm');
% ylabel(ax(2), 'Length in mm');
% xlim([minb maxb]);
% p1.Marker = '*';
% p1.LineWidth = 2;
% p2.Marker = '+';
% p2.LineWidth = 2;

end
% vline = line([280,280],[50,500]);
% vline.Color = 'r';
% hline = refline([0,72]);
% hline.Color = 'r';
% hold off;
% colorVec = hsv(10);
% 
% figure(2);
% hold on;
% for i=minb:bwidth:maxb  
% 
% ratio = l == i;
% 
% 
% S = solve([constant, stress, frequency, ratio], [b,h,l,kz]);
% 
% B = double(S.b);
% H = double(S.h);
% L = double(S.l);
% Kz = double(S.kz);
% 
% p2 = plot(i, H*1000, i, B);
% p2(1).Marker = '*';
% p2(1).LineWidth = 2;
% p2(2).Marker = '+';
% 
% end
% hold off;


%% Plot Fixed L/B Ratio

minlb = 1.5; % Min value of b
maxlb = 5; % Max value of b
lbwidth = 0.25; %Stepwidth for b

figure(3);

hold on;
for i=minlb:lbwidth:maxlb  

ratio = l == i*b;
condition = b>0;


S = solve([constant, stress, frequency, ratio, condition], [b,h,l,kz]);

B = double(S.b);
H = double(S.h);
L = double(S.l);
Kz = double(S.kz);

p = plot(i, B*1000, 'b.', i, L*1000, 'g.');
title('Width and Lenght as fonction of L/B')
xlabel('L/B');
legend('Width in mm', 'Lenght in mm')
% set(0,'defaultaxescolororder',[b; g]) %black and gray
% set(0,'defaultaxeslinestyleorder',{'-*',':'}) %or whatever you want
% p(1).Marker = '*';
% p(2).Marker = '+';
% ylabel(p(1), 'Height in mm');
% ylabel(p(2), 'Length in mm');

% [ax,p1,p2] = plotyy(B, H*1000, B, L);
% ylabel(ax(1), 'Height in mm');
% ylabel(ax(2), 'Length in mm');
% xlim([minb maxb]);
% p1.Marker = '*';
% p1.LineWidth = 2;
% p2.Marker = '+';
% p2.LineWidth = 2;

end
hline = refline([0,72]);
hline.Color = 'r';
hline = refline([0,280]);
hline.Color = 'r';
hold off;

%% Calculate Fixed B

fixedb = 85; %width in mm
ratio = b == fixedb/1000;


S = solve([constant, stress, frequency, ratio], [b,h,l,kz]);

disp(strcat('The solution for a fixed B = ', num2str(fixedb), ' mm'))

B = double(S.b)*1000;
H = double(S.h)*1000
L = double(S.l)*1000
Kz = double(S.kz)
TipDeflection = P/Kz

%% Calculate Fixed L

fixedl = 280; %length in mm
ratio = l == fixedl/1000;


S = solve([constant, stress, frequency, ratio], [b,h,l,kz]);

disp(strcat('The solution for a fixed L = ', num2str(fixedl), ' mm'))

B = double(S.b)*1000
H = double(S.h)*1000
L = double(S.l)*1000
Kz = double(S.kz)
TipDeflection = P/Kz

%% Calculate & Graphics for Fixed L

fixedl = 280; %length in mm
ratio = l == fixedl/1000;
figure(4);
% hold on;

% for i = 1.5:0.05:3.5
    
    
   
% S = solve([kz == E*b*h^3/(4*l^3*alpha), SY/FoS == 6*P*l/(b*h^2), (2*pi*f)^2 == nblades*kz/m, ratio], [b,h,l,kz]);
% 
% %disp(strcat('The solution for a fixed L = ', num2str(fixedl), ' mm'))
% 
% B = double(S.b)*1000;
% H = double(S.h)*1000;
% L = double(S.l)*1000;
% Kz = double(S.kz);
% 
% % p = plotyy(FoS, H*10, 'b.', FoS, B, 'g.');
% p = plotyy(FoS, H*10, FoS, B);

X = 2:0.0001:4; % FoS for the plot
HH = 2.*4.*alpha./nblades./3.*pi.^2.*f.^2.*(fixedl./1000).^2.*m.*SY./(E.*P.*X)*1000;
BB = nblades.^2.*6.^3.*E.^2.*P.^3.*X.^3/(4.^4.*alpha.^2.*pi.^4)./(f.^4.*SY.^3.*(fixedl./1000).^3.*m.^2).*1000;
p = plotyy(X, HH, X, BB);
ylabel(p(1), 'Height in mm');
ylabel(p(2), 'Width in mm');
title(strcat('Width and Height as fonction of FoS for', ' Lenght =  ', num2str(fixedl), 'mm, f =', num2str(f), 'Hz and m =  ', num2str(m),'kg'));
xlabel('FoS');
% 
% legend('Height in 100 um', 'Width in mm')

% end




%% Calculate Bend Radius

% symvar radius; % Bend Radius  
TipDeflection = P/Kz% Tip Deflection in m
Q = solve('TipDeflection = radius*(1-cos(L/1000/radius))', 'radius');
radA = double(Q.radius)*1000; % Bend Radius in mm for MethodA
Ib = (B/1000)*(H/1000)^3/12; % Inertia of the Root section in m^4
M = L/1000*P;
radB = E*I/M

%% Calculate FoS and H with fixed L and B
fixedl = 280; %length in mm
fixedb = 85; % width in mm
f = 1.50; % frequency in Hz

Kz = (2.*pi.*f).^2.*m./nblades
H = (Kz*4*(fixedl/1000)^3*alpha/(E*(fixedb/1000)))^(1/3)*1000
FoSI = SY/(6.*P.*(fixedl./1000)./((fixedb./1000).*(H./1000).^2))


%% Calculate FoS and f with fixed L, H and B
fixedl = 280; %length in mm
fixedb = 85; % width in mm
fixedh = 0.0835*25.4; % thickness in mm
mI = 36; % total suspended mass in kg


Kz = (E*(fixedb/1000)*(fixedh/1000)^3)/(4*(fixedl/1000)^3*alpha)
f=1/(2*pi)*(Kz.*nblades/mI)^(1/2)
FoSII = SY/(6.*(9.81*mI/3).*(fixedl./1000)./((fixedb./1000).*(fixedh./1000).^2))
