% Base BOLTS Calculation
% Attention: Takes P from BladeDesign.m

GeneralProperties;


% Geometry
dbe = 255; % Distance perpendicular to g between the extreme of the blade and the closest blot of the base (mm)
dbb = 12.2; % Distance between the two range of bolts in the base (mm)

% Screw Area Calculation
dp = ds-0.649519*ls; %Pitch diameter m
dm = ds-1.299038*ls; %Minor diameter m
As = pi/4*((dp + dm)/2)^2 % area of the screw [m^2]

% Total Axial Load
Pb = P*dbe/dbb %Total Axial Load in N

% Axial Load per Screw
Pbs = SYs/FoSs*As %[N]

%Number of Screws
screwnum = ceil(Pb/Pbs)

% Preload Torque
T = Pbs*(0.159*ls+1.156*mus*ds) % Torque in Nm

%Real FoS
RealFoS = Pbs*FoSs/Pb*screwnum




% % Properties in no SI
% 
% Plb = P/0.2248090247334889; % Weight per Blade in lbf
% % Geometry
% 
% dbe = 255; % Distance perpendicular to g between the extreme of the blade and the closest blot of the base (mm)
% dbb = 20; % Distance between the two range of bolts in the base (mm)
% 
% % Material
% % 316 Stainless Steel
% SYs = 290*145; % Yield Stress of the Screw in Psi
% 
% %Screw
% %1/4-20
% mus = 0.117; % Friction coeficient 
% ls = 1/20; % Pitch of the Screw in in
% ds = 1/4; %Screw diameter in in
% dp = ds-0.649519*ls; %Pitch diameter in
% dm = ds-1.299038*ls; %Minor diameter in
% As = pi/4*((dp + dm)/2)^2; % area of the screw [in^2]
% 
% 
% % FoS
% FoSs = 1.5; % FoS of the screw
% 
% 
% 
% % Total Axial Load
% Pb = Plb*dbe/dbb; %Total Axial Load in lbf
% 
% % Axial Load per Screw
% Pbs = SYs/FoSs*As; %[lbf]
% 
% %Number of Screws
% screwnum = ceil(Pb/Pbs)
% 
% % Preload Torque
% T = Pb*(0.159*ls+1.156*mus*ds)*0.112984829333; % Torque in Nm

%% Fixer Screw Calculation

dsf = 0.19*0.0254; %Diameter in m (#10)
lsf = 1/24*0.0254; % Pitch of the Screw in m

% Screw Area Calculation
dp = dsf-0.649519*lsf; %Pitch diameter m
dm = dsf-1.299038*lsf; %Minor diameter m
As = pi/4*((dp + dm)/2)^2 % area of the screw [m^2]
FoSf = SYs/P*As


% % Total Axial Load
% Pbf = P %Total Axial Load in N
% 
% % Axial Load per Screw
% Pbsf = SYs/FoSs*As %[N]

% %Number of Screws
% screwnumf = ceil(Pbf/Pbsf)
% 
% % Preload Torque
% Tf = Pbsf*(0.159*lsf+1.156*mus*dsf) % Torque in Nm
% 
% %Real FoS
% RealFoSf = Pbsf*FoSs/Pbf*screwnumf