%  FLEXURE STUDY
% Attention: Uses P, nblades and m values from GeneralProperties


GeneralProperties;

 % Unit Conversion
 d = d/1000; % mm to m
 lf = lf/1000; % mm to m


% Minimum Diameter Calculation
% Simplified for the moment with a high FoS

% dmin = sqrt(P*4/pi/(SYf/FoSf))*1000; % Minimum d in mm
% if dmin >= d
%   h = msgbox(strcat('Dmin NOT respected. ', ' Dmin = ', num2str(dmin), ' mm'));  
%   d = dmin;
% end

% ZMP, Section & lz Calculation
I = pi*d^4/64; % Inertia in m4
v = sqrt(P/(Ef*I)); % Constant in 1/m
ZMP = 1/v*tanh(v*lf/2)*1000 % ZMP in mm
lz = lf*1000 - 2*ZMP % Effective lenght in mm
Sec = pi*d^2/4; % Wire Section in m2


% Shear Stress
Tmax = P*delta/(Sec*lz/1000) % Maximum shear stress in Pa

% Axial Stress
Smax = 4/pi*P/d^2*(1+8*ZMP/1000*delta/(d*lz/1000))% Maximum axial stress in Pa
Snorm = P/Sec
Sbend = P*ZMP/1000*d/2*delta/(I*lz/1000)


% Equivalent Axial Stress
Seq = sqrt(Smax^2+3*Tmax^2) % Equivalent Stress in Pa

% FoS
FoSf = SYf/Seq % Factor of Safety


% Stiffness & Horizontal frequency
kxx = m*9.81/(nblades*(lz/1000)) %Horizontal Stifness (kxx = kyy) [N/m]
kyy = kxx;
fxx = sqrt(kxx*3/m)/(2*pi) % Frequency in Hz

%% GRAPHIC
figure();
% FoS as function of D 
mind = .5; % Min value of d mm
maxd = .75; % Max value of d mm
dwidth = 0.0001; %Stepwidth for d mm
hold on;

% % dx = 0.0004;
d=mind/1000:dwidth/1000:maxd/1000;
p = plot(d*1000, SYf./sqrt(power(4./pi.*P./(power(d,2)).*(1+8.*ZMP./1000.*delta./(d.*lz./1000)),2)+power(3.*P.*delta./(Sec.*lz./1000),2)));
title(strcat('FoS function of D for', ' Lf = ', num2str(lf*1000), ' mm and m = ', num2str(m),' kg'));
xlabel('Wire diameter (mm)');
ylabel('FoS');
% xlim([mind-dwidth maxd+dwidth]);
% end 

%% Elongation

elong = Snorm/Ef
deltalength = elong*lf*1000 %expected deformation in mm